.. py:currentmodule:: drdmannturb


Rapid Distortion Power Spectra
------------------------------

.. py:currentmodule:: drdmannturb.spectra_fitting.power_spectra_rdt

.. autofunction:: PowerSpectraRDT
